@@ -59,7 +59,7 @@ impl<JS: rt::JobStateValues, TS: rt::TaskStateValues> Filter<JS, TS> for Redirec
 
 		let location = status.headers.get_str(http::header::LOCATION)?;
 
-		let link = rt::Link::new(&location, "", "", "", task.link.redirect + 1, task.link.target, &task.link)
+		let link = rt::Link::new(location, "", "", "", task.link.redirect + 1, task.link.target, &task.link)
 			.context("cannot create link")?;
 
 		ctx.push_links(vec![link]);
